==> lens-6.0.0.tar.gz: lens-6.0.0/src/renderer/themes/lens-dark.ts <==
/**
 * Copyright (c) OpenLens Authors. All rights reserved.
 * Licensed under MIT License. See LICENSE in root directory for more information.
 */

import type { Theme } from "./store";

const lensDarkTheme: Theme = {
  "name": "Dark",
  "type": "dark",
  "description": "Original Lens dark theme",
  "author": "Mirantis",
  "monacoTheme": "clouds-midnight",
  "colors": {
    "blue": "#3d90ce",
    "magenta": "#c93dce",
    "golden": "#ffc63d",
    "halfGray": "#87909c80",
    "primary": "#3d90ce",
    "textColorPrimary": "#8e9297",
    "textColorSecondary": "#a0a0a0",
    "textColorTertiary": "#909ba6",
    "textColorAccent": "#ffffff",
    "textColorDimmed": "#8e92978c",
    "borderColor": "#4c5053",
    "borderFaintColor": "#373a3e",
    "mainBackground": "#1e2124",
    "secondaryBackground": "#1e2125",
    "contentColor": "#262b2f",
    "layoutBackground": "#2e3136",
    "layoutTabsBackground": "#252729",
    "layoutTabsActiveColor": "#ffffff",
    "layoutTabsLineColor": "#87909c80",
    "sidebarBackground": "#36393e",
    "sidebarLogoBackground": "#414448",
    "sidebarActiveColor": "#ffffff",
    "sidebarSubmenuActiveColor": "#ffffff",
    "sidebarItemHoverBackground": "#3a3e44",
    "badgeBackgroundColor": "#ffba44",
    "buttonPrimaryBackground": "#3d90ce",
    "buttonDefaultBackground": "#414448",
    "buttonLightBackground": "#f1f1f1",
    "buttonAccentBackground": "#e85555",
    "buttonDisabledBackground": "#808080",
    "tableBgcStripe": "#2a2d33",
    "tableBgcSelected": "#383c42",
    "tableHeaderBackground": "#262b2f",
    "tableHeaderBorderWidth": "1px",
    "tableHeaderBorderColor": "#36393e",
    "tableHeaderColor": "#ffffff",
    "tableSelectedRowColor": "#ffffff",
    "helmLogoBackground": "#ffffff",
    "helmStableRepo": "#3d90ce",
    "helmIncubatorRepo": "#ff7043",
    "helmDescriptionHr": "#41474a",
    "helmDescriptionBlockquoteColor": "#bbb",
    "helmDescriptionBlockquoteBorder": "#8a8f93",
    "helmDescriptionBlockquoteBackground": "#3b4348",
    "helmDescriptionHeaders": "#3e4147",
    "helmDescriptionH6": "#6a737d",
    "helmDescriptionTdBorder": "#47494a",
    "helmDescriptionTrBackground": "#1c2125",
    "helmDescriptionCodeBackground": "#ffffff1a",
    "helmDescriptionPreBackground": "#1b1f21",
    "helmDescriptionPreColor": "#b4b5b4",
    "colorSuccess": "#43a047",
    "colorOk": "#4caf50",
    "colorInfo": "#3d90ce",
    "colorError": "#ce3933",
    "colorSoftError": "#e85555",
    "colorWarning": "#ff9800",
    "colorVague": "#36393e",
    "colorTerminated": "#4c5053",
    "dockHeadBackground": "#2e3136",
    "dockInfoBackground": "#1e2125",
    "dockInfoBorderColor": "#303136",
    "dockEditorBackground": "#000000",
    "dockEditorTag": "#8e97a3",
    "dockEditorKeyword": "#ffffff",
    "dockEditorComment": "#808080",
    "dockEditorActiveLineBackground": "#3a3d41",
    "dockBadgeBackground": "#36393e",
    "dockTabBorderColor": "#43424d",
    "dockTabActiveBackground": "#3a3e45",
    "logsBackground": "#000000",
    "logsForeground": "#ffffff",
    "logRowHoverBackground": "#35373a",
    "terminalBackground": "#000000",
    "terminalForeground": "#ffffff",
    "terminalCursor": "#ffffff",
    "terminalCursorAccent": "#000000",
    "terminalSelection": "#ffffff77",
    "terminalBlack": "#2e3436",
    "terminalRed": "#cc0000",
    "terminalGreen": "#4e9a06",
    "terminalYellow": "#c4a000",
    "terminalBlue": "#3465a4",
    "terminalMagenta": "#75507b",
    "terminalCyan": "#06989a",
    "terminalWhite": "#d3d7cf",
    "terminalBrightBlack": "#555753",
    "terminalBrightRed": "#ef2929",
    "terminalBrightGreen": "#8ae234",
    "terminalBrightYellow": "#fce94f",
    "terminalBrightBlue": "#729fcf",
    "terminalBrightMagenta": "#ad7fa8",
    "terminalBrightCyan": "#34e2e2",
    "terminalBrightWhite": "#eeeeec",
    "dialogTextColor": "#87909c",
    "dialogBackground": "#ffffff",
    "dialogHeaderBackground": "#36393e",
    "dialogFooterBackground": "#f4f4f4",
    "drawerTogglerBackground": "#2f343a",
    "drawerTitleText": "#ffffff",
    "drawerSubtitleBackground": "#373a3e",
    "drawerItemNameColor": "#87909c",
    "drawerItemValueColor": "#a0a0a0",
    "clusterMenuBackground": "#252729",
    "clusterMenuBorderColor": "#252729",
    "clusterMenuCellBackground": "#2e3136",
    "clusterSettingsBackground": "#1e2124",
    "addClusterIconColor": "#252729",
    "boxShadow": "#0000003a",
    "iconActiveColor": "#ffffff",
    "iconActiveBackground": "#ffffff18",
    "filterAreaBackground": "#23272b",
    "chartLiveBarBackground": "#00000033",
    "chartStripesColor": "#ffffff08",
    "chartCapacityColor": "#4c545f",
    "pieChartDefaultColor": "#30353a",
    "inputOptionHoverColor": "#87909c",
    "inputControlBackground": "#1e2125",
    "inputControlBorder": "#414448",
    "inputControlHoverBorder": "#474a4f",
    "lineProgressBackground": "#414448",
    "radioActiveBackground": "#36393e",
    "menuActiveBackground": "#3d90ce",
    "menuSelectedOptionBgc": "#36393e",
    "canvasBackground": "#24292e",
    "scrollBarColor": "#5f6064",
    "settingsBackground": "#262b2e",
    "settingsColor": "#909ba6",
    "navSelectedBackground": "#262b2e",
    "navHoverColor": "#dcddde",
    "hrColor": "#ffffff0f",
    "tooltipBackground": "#18191c",
  },
};

export default lensDarkTheme;

==> lens-6.1.18.tar.gz: lens-6.1.18/src/renderer/themes/lens-dark.ts <==
/**
 * Copyright (c) OpenLens Authors. All rights reserved.
 * Licensed under MIT License. See LICENSE in root directory for more information.
 */

import type { LensTheme } from "./store";

const lensDarkTheme: LensTheme = {
  "name": "Dark",
  "type": "dark",
  "description": "Original Lens dark theme",
  "author": "Mirantis",
  "monacoTheme": "clouds-midnight",
  "colors": {
    "blue": "#3d90ce",
    "magenta": "#c93dce",
    "golden": "#ffc63d",
    "halfGray": "#87909c80",
    "primary": "#3d90ce",
    "textColorPrimary": "#8e9297",
    "textColorSecondary": "#a0a0a0",
    "textColorTertiary": "#909ba6",
    "textColorAccent": "#ffffff",
    "textColorDimmed": "#8e92978c",
    "borderColor": "#4c5053",
    "borderFaintColor": "#373a3e",
    "mainBackground": "#1e2124",
    "secondaryBackground": "#1e2125",
    "contentColor": "#262b2f",
    "layoutBackground": "#2e3136",
    "layoutTabsBackground": "#252729",
    "layoutTabsActiveColor": "#ffffff",
    "layoutTabsLineColor": "#87909c80",
    "sidebarBackground": "#36393e",
    "sidebarLogoBackground": "#414448",
    "sidebarActiveColor": "#ffffff",
    "sidebarSubmenuActiveColor": "#ffffff",
    "sidebarItemHoverBackground": "#3a3e44",
    "badgeBackgroundColor": "#ffba44",
    "buttonPrimaryBackground": "#3d90ce",
    "buttonDefaultBackground": "#414448",
    "buttonLightBackground": "#f1f1f1",
    "buttonAccentBackground": "#e85555",
    "buttonDisabledBackground": "#808080",
    "tableBgcStripe": "#2a2d33",
    "tableBgcSelected": "#383c42",
    "tableHeaderBackground": "#262b2f",
    "tableHeaderBorderWidth": "1px",
    "tableHeaderBorderColor": "#36393e",
    "tableHeaderColor": "#ffffff",
    "tableSelectedRowColor": "#ffffff",
    "helmLogoBackground": "#ffffff",
    "helmStableRepo": "#3d90ce",
    "helmIncubatorRepo": "#ff7043",
    "helmDescriptionHr": "#41474a",
    "helmDescriptionBlockquoteColor": "#bbb",
    "helmDescriptionBlockquoteBorder": "#8a8f93",
    "helmDescriptionBlockquoteBackground": "#3b4348",
    "helmDescriptionHeaders": "#3e4147",
    "helmDescriptionH6": "#6a737d",
    "helmDescriptionTdBorder": "#47494a",
    "helmDescriptionTrBackground": "#1c2125",
    "helmDescriptionCodeBackground": "#ffffff1a",
    "helmDescriptionPreBackground": "#1b1f21",
    "helmDescriptionPreColor": "#b4b5b4",
    "colorSuccess": "#43a047",
    "colorOk": "#4caf50",
    "colorInfo": "#3d90ce",
    "colorError": "#ce3933",
    "colorSoftError": "#e85555",
    "colorWarning": "#ff9800",
    "colorVague": "#36393e",
    "colorTerminated": "#4c5053",
    "dockHeadBackground": "#2e3136",
    "dockInfoBackground": "#1e2125",
    "dockInfoBorderColor": "#303136",
    "dockEditorBackground": "#000000",
    "dockEditorTag": "#8e97a3",
    "dockEditorKeyword": "#ffffff",
    "dockEditorComment": "#808080",
    "dockEditorActiveLineBackground": "#3a3d41",
    "dockBadgeBackground": "#36393e",
    "dockTabBorderColor": "#43424d",
    "dockTabActiveBackground": "#3a3e45",
    "logsBackground": "#000000",
    "logsForeground": "#ffffff",
    "logRowHoverBackground": "#35373a",
    "terminalBackground": "#000000",
    "terminalForeground": "#ffffff",
    "terminalCursor": "#ffffff",
    "terminalCursorAccent": "#000000",
    "terminalSelection": "#ffffff77",
    "terminalBlack": "#2e3436",
    "terminalRed": "#cc0000",
    "terminalGreen": "#4e9a06",
    "terminalYellow": "#c4a000",
    "terminalBlue": "#3465a4",
    "terminalMagenta": "#75507b",
    "terminalCyan": "#06989a",
    "terminalWhite": "#d3d7cf",
    "terminalBrightBlack": "#555753",
    "terminalBrightRed": "#ef2929",
    "terminalBrightGreen": "#8ae234",
    "terminalBrightYellow": "#fce94f",
    "terminalBrightBlue": "#729fcf",
    "terminalBrightMagenta": "#ad7fa8",
    "terminalBrightCyan": "#34e2e2",
    "terminalBrightWhite": "#eeeeec",
    "dialogTextColor": "#87909c",
    "dialogBackground": "#ffffff",
    "dialogHeaderBackground": "#36393e",
    "dialogFooterBackground": "#f4f4f4",
    "drawerTogglerBackground": "#2f343a",
    "drawerTitleText": "#ffffff",
    "drawerSubtitleBackground": "#373a3e",
    "drawerItemNameColor": "#87909c",
    "drawerItemValueColor": "#a0a0a0",
    "clusterMenuBackground": "#252729",
    "clusterMenuBorderColor": "#252729",
    "clusterMenuCellBackground": "#2e3136",
    "clusterSettingsBackground": "#1e2124",
    "addClusterIconColor": "#252729",
    "boxShadow": "#0000003a",
    "iconActiveColor": "#ffffff",
    "iconActiveBackground": "#ffffff18",
    "filterAreaBackground": "#23272b",
    "chartLiveBarBackground": "#00000033",
    "chartStripesColor": "#ffffff08",
    "chartCapacityColor": "#4c545f",
    "pieChartDefaultColor": "#30353a",
    "inputOptionHoverColor": "#87909c",
    "inputControlBackground": "#1e2125",
    "inputControlBorder": "#414448",
    "inputControlHoverBorder": "#474a4f",
    "lineProgressBackground": "#414448",
    "radioActiveBackground": "#36393e",
    "menuActiveBackground": "#3d90ce",
    "menuSelectedOptionBgc": "#36393e",
    "canvasBackground": "#24292e",
    "scrollBarColor": "#5f6064",
    "settingsBackground": "#262b2e",
    "settingsColor": "#909ba6",
    "navSelectedBackground": "#262b2e",
    "navHoverColor": "#dcddde",
    "hrColor": "#ffffff0f",
    "tooltipBackground": "#18191c",
  },
};

export default lensDarkTheme;
